@@ -37,9 +37,12 @@ DAYS_OF_WEEK = (
 )
 
 
-def get_time(data=time.time(), template='%d.%m.%Y %H:%M:%S', tz=0):
+def get_time(data=None, template='%d.%m.%Y %H:%M:%S', tz=0):
     """ Get time from timestamp """
 
+    if data is None:
+        data = time.time()
+
     # TODO: smart TZ
 
     if isinstance(data, datetime.datetime):
